      DOUBLE PRECISION FUNCTION MAP_STEEL_CULRAT
     &(T,TINT,C1,C2,CURR,VOLT,EFF,SPEED)
C
C     FUNCTION TO GET COOLING RATE AT TEMPERATURE T using equation 1(b) in the 
C     paper by L.-E. Svensson, B. Gretoft and H.K.D.H Bhadeshia, Scandinavian
C     Journal of Metallurgy, 1986, vol. 15, 97-103.
C     T      - the temperature (Kelvin)
C     TINT   - the interpass or preheat temperature (Kelvin)
C     C1     - the heat flow constant from equation 1(b) 
C     C2     - the heat flow constant from equation 1(b)
C     CURR   - the welding current (Amperes)
C     VOLT   - welding voltage (Volts)
C     EFF    - the arc transfer efficiency
C     SPEED  - the welding speed (metres/second)
C     CULRAT - the cooling rate (Kelvin/second)
C
      IMPLICIT NONE
      DOUBLE PRECISION T,TINT,C1,C2,CURR,VOLT,EFF,SPEED
      DOUBLE PRECISION MAP_STEEL_CULRAT,CULRAT
C
      CULRAT=(T-TINT)**C2
      MAP_STEEL_CULRAT=CULRAT*C1*SPEED/(CURR*VOLT*EFF)
      RETURN
      END
